[Bf-blender-cvs] [87a7149] master: BPY Docs: Correct spelling (Addon --> Add-on)

Aaron Carlisle noreply at git.blender.org
Fri Oct 14 01:27:07 CEST 2016


Commit: 87a71498319913866b16834b590b25d313c84114
Author: Aaron Carlisle
Date:   Fri Oct 14 01:23:29 2016 +0200
Branches: master
https://developer.blender.org/rB87a71498319913866b16834b590b25d313c84114

BPY Docs: Correct spelling (Addon --> Add-on)

Differential Revision: https://developer.blender.org/D2293

===================================================================

M	doc/python_api/examples/bpy.app.handlers.1.py
M	doc/python_api/examples/bpy.app.translations.py
M	doc/python_api/examples/bpy.types.AddonPreferences.1.py
M	doc/python_api/examples/bpy.types.Menu.2.py
M	doc/python_api/examples/bpy.types.PropertyGroup.py
M	doc/python_api/rst/info_overview.rst
M	doc/python_api/rst/info_tutorial_addon.rst
M	doc/python_api/sphinx_doc_gen.py

===================================================================

diff --git a/doc/python_api/examples/bpy.app.handlers.1.py b/doc/python_api/examples/bpy.app.handlers.1.py
index 48fdb95..245ac19 100644
--- a/doc/python_api/examples/bpy.app.handlers.1.py
+++ b/doc/python_api/examples/bpy.app.handlers.1.py
@@ -4,7 +4,7 @@ Persistent Handler Example
 
 By default handlers are freed when loading new files, in some cases you may
 wan't the handler stay running across multiple files (when the handler is
-part of an addon for example).
+part of an add-on for example).
 
 For this the :data:`bpy.app.handlers.persistent` decorator needs to be used.
 """
diff --git a/doc/python_api/examples/bpy.app.translations.py b/doc/python_api/examples/bpy.app.translations.py
index 6ea749c..41b024a 100644
--- a/doc/python_api/examples/bpy.app.translations.py
+++ b/doc/python_api/examples/bpy.app.translations.py
@@ -5,7 +5,7 @@ Intro
 .. warning::
 
    Most of this object should only be useful if you actually manipulate i18n stuff from Python.
-   If you are a regular addon, you should only bother about :const:`contexts` member,
+   If you are a regular add-on, you should only bother about :const:`contexts` member,
    and the :func:`register`/:func:`unregister` functions! The :func:`pgettext` family of functions
    should only be used in rare, specific cases (like e.g. complex "composited" UI strings...).
 
@@ -21,7 +21,7 @@ Intro
 Then, call ``bpy.app.translations.register(__name__, your_dict)`` in your ``register()`` function, and
 ``bpy.app.translations.unregister(__name__)`` in your ``unregister()`` one.
 
-The ``Manage UI translations`` addon has several functions to help you collect strings to translate, and
+The ``Manage UI translations`` add-on has several functions to help you collect strings to translate, and
 generate the needed python code (the translation dictionary), as well as optional intermediary po files
 if you want some... See
 `How to Translate Blender <http://wiki.blender.org/index.php/Dev:Doc/Process/Translate_Blender>`_ and
diff --git a/doc/python_api/examples/bpy.types.Menu.2.py b/doc/python_api/examples/bpy.types.Menu.2.py
index 86288b5..50460f6 100644
--- a/doc/python_api/examples/bpy.types.Menu.2.py
+++ b/doc/python_api/examples/bpy.types.Menu.2.py
@@ -2,9 +2,9 @@
 Extending Menus
 +++++++++++++++
 
-When creating menus for addons you can't reference menus in Blender's default
-scripts.
-Instead, the addon can add menu items to existing menus.
+When creating menus for add-ons you can't reference menus
+in Blender's default scripts.
+Instead, the add-on can add menu items to existing menus.
 
 The function menu_draw acts like :class:`Menu.draw`.
 """
diff --git a/doc/python_api/examples/bpy.types.PropertyGroup.py b/doc/python_api/examples/bpy.types.PropertyGroup.py
index d5260bf..2c2aa6d 100644
--- a/doc/python_api/examples/bpy.types.PropertyGroup.py
+++ b/doc/python_api/examples/bpy.types.PropertyGroup.py
@@ -13,7 +13,7 @@ be animated, accessed from the user interface and from python.
    definitions are not, this means whenever you load blender the class needs
    to be registered too.
 
-   This is best done by creating an addon which loads on startup and registers
+   This is best done by creating an add-on which loads on startup and registers
    your properties.
 
 .. note::
diff --git a/doc/python_api/rst/info_overview.rst b/doc/python_api/rst/info_overview.rst
index 960dd07..07c7d57 100644
--- a/doc/python_api/rst/info_overview.rst
+++ b/doc/python_api/rst/info_overview.rst
@@ -77,22 +77,22 @@ To run as modules:
 - The obvious way, ``import some_module`` command from the text window or interactive console.
 - Open as a text block and tick "Register" option, this will load with the blend file.
 - copy into one of the directories ``scripts/startup``, where they will be automatically imported on startup.
-- define as an addon, enabling the addon will load it as a Python module.
+- define as an add-on, enabling the add-on will load it as a Python module.
 
 
-Addons
+Add-ons
 ------
 
 Some of Blenders functionality is best kept optional,
-alongside scripts loaded at startup we have addons which are kept in their own directory ``scripts/addons``,
+alongside scripts loaded at startup we have add-ons which are kept in their own directory ``scripts/addons``,
 and only load on startup if selected from the user preferences.
 
-The only difference between addons and built-in Python modules is that addons must contain a ``bl_info``
+The only difference between add-ons and built-in Python modules is that add-ons must contain a ``bl_info``
 variable which Blender uses to read metadata such as name, author, category and URL.
 
-The user preferences addon listing uses **bl_info** to display information about each addon.
+The User Preferences add-on listing uses **bl_info** to display information about each add-on.
 
-`See Addons <http://wiki.blender.org/index.php/Dev:2.5/Py/Scripts/Guidelines/Addons>`__
+`See Add-ons <http://wiki.blender.org/index.php/Dev:2.5/Py/Scripts/Guidelines/Addons>`__
 for details on the ``bl_info`` dictionary.
 
 
@@ -223,7 +223,7 @@ These functions usually appear at the bottom of the script containing class regi
 You can also use them for internal purposes setting up data for your own tools but take care
 since register won't re-run when a new blend file is loaded.
 
-The register/unregister calls are used so it's possible to toggle addons and reload scripts while Blender runs.
+The register/unregister calls are used so it's possible to toggle add-ons and reload scripts while Blender runs.
 If the register calls were placed in the body of the script, registration would be called on import,
 meaning there would be no distinction between importing a module or loading its classes into Blender.
 
diff --git a/doc/python_api/rst/info_tutorial_addon.rst b/doc/python_api/rst/info_tutorial_addon.rst
index 239c288..9326f80 100644
--- a/doc/python_api/rst/info_tutorial_addon.rst
+++ b/doc/python_api/rst/info_tutorial_addon.rst
@@ -1,6 +1,6 @@
 
-Addon Tutorial
-##############
+Add-on Tutorial
+###############
 
 ************
 Introduction
@@ -36,6 +36,7 @@ Suggested reading before starting this tutorial.
 To best troubleshoot any error message Python prints while writing scripts you run blender with from a terminal,
 see :ref:`Use The Terminal <use_the_terminal>`.
 
+
 Documentation Links
 ===================
 
@@ -46,51 +47,48 @@ While going through the tutorial you may want to look into our reference documen
 - :mod:`bpy.context` api reference. -
   *Handy to have a list of available items your script may operate on.*
 - :class:`bpy.types.Operator`. -
-  *The following addons define operators, these docs give details and more examples of operators.*
-
+  *The following add-ons define operators, these docs give details and more examples of operators.*
 
-******
-Addons
-******
 
+*******
+Add-ons
+*******
 
-What is an Addon?
-=================
+What is an Add-on?
+==================
 
-An addon is simply a Python module with some additional requirements so Blender can display it in a list with useful
+An add-on is simply a Python module with some additional requirements so Blender can display it in a list with useful
 information.
 
-To give an example, here is the simplest possible addon.
-
+To give an example, here is the simplest possible add-on.
 
 .. code-block:: python
 
-   bl_info = {"name": "My Test Addon", "category": "Object"}
+   bl_info = {"name": "My Test Add-on", "category": "Object"}
    def register():
        print("Hello World")
    def unregister():
        print("Goodbye World")
 
 
-- ``bl_info`` is a dictionary containing addon meta-data such as the title, version and author to be displayed in the
-  user preferences addon list.
-- ``register`` is a function which only runs when enabling the addon, this means the module can be loaded without
-  activating the addon.
-- ``unregister`` is a function to unload anything setup by ``register``, this is called when the addon is disabled.
-
+- ``bl_info`` is a dictionary containing add-on metadata such as the title,
+  version and author to be displayed in the user preferences add-on list.
+- ``register`` is a function which only runs when enabling the add-on,
+  this means the module can be loaded without activating the add-on.
+- ``unregister`` is a function to unload anything setup by ``register``, this is called whe

@@ Diff output truncated at 10240 characters. @@




More information about the Bf-blender-cvs mailing list
diff --git a/doc/python_api/examples/bpy.types.AddonPreferences.1.py b/doc/python_api/examples/bpy.types.AddonPreferences.1.py
index 7a065db..e478ba9 100644
--- a/doc/python_api/examples/bpy.types.AddonPreferences.1.py
+++ b/doc/python_api/examples/bpy.types.AddonPreferences.1.py
@@ -1,10 +1,10 @@
 bl_info = {
-    "name": "Example Addon Preferences",
+    "name": "Example Add-on Preferences",
     "author": "Your Name Here",
     "version": (1, 0),
     "blender": (2, 65, 0),
-    "location": "SpaceBar Search -> Addon Preferences Example",
-    "description": "Example Addon",
+    "location": "SpaceBar Search -> Add-on Preferences Example",
+    "description": "Example Add-on",
     "warning": "",
     "wiki_url": "",
     "tracker_url": "",
@@ -18,7 +18,7 @@ from bpy.props import StringProperty, IntProperty, BoolProperty
 
 
 class ExampleAddonPreferences(AddonPreferences):
     # this must match the addon name, use '__package__'
     # when defining this in a submodule of a python package.
     bl_idname = __name__
 
@@ -37,7 +37,7 @@ class ExampleAddonPreferences(AddonPreferences):
 
     def draw(self, context):
         layout = self.layout
-        layout.label(text="This is a preferences view for our addon")
+        layout.label(text="This is a preferences view for our add-on")
         layout.prop(self, "filepath")
         layout.prop(self, "number")
         layout.prop(self, "boolean")
@@ -46,7 +46,7 @@ class ExampleAddonPreferences(AddonPreferences):
 class OBJECT_OT_addon_prefs_example(Operator):
     """Display example preferences"""
     bl_idname = "object.addon_prefs_example"
-    bl_label = "Addon Preferences Example"
+    bl_label = "Add-on Preferences Example"
     bl_options = {'REGISTER', 'UNDO'}
 
     def execute(self, context):
@@ -18,7 +18,7 @@ from bpy.props import StringProperty, IntProperty, BoolProperty
 
 class ExampleAddonPreferences(AddonPreferences):
-    # this must match the addon name, use '__package__'
+    # this must match the add-on name, use '__package__'
     # when defining this in a submodule of a python package.
     bl_idname = __name__